==> waylay_beta-0.4.0-py3-none-any.whl: waylay/service/data/events.py <==
"""REST definitions for the 'series' entity of the 'data' service."""

from waylay.service import WaylayResource
from waylay.service import decorators

DEFAULT_DECORATORS = [decorators.exception_decorator, decorators.return_body_decorator]


class EventsResource(WaylayResource):
    """REST Resource for the 'events' ingestion of the 'data' service."""

    link_roots = {
        'doc': '${doc_url}/api/broker/?id='
    }

    actions = {
        'post': {
            'method': 'POST', 'url': '/resources/{}/events',
            'decorators': [
                decorators.exception_decorator,
                decorators.return_path_decorator([]),
            ],
            'description': (
                'Forward a json message to the rule engine, '
                'time series database and/or document store for a given resource.'
            ),
            'links': {
                'doc': 'posting-data-to-the-storage-and-rule-engine'
            },
        },
        'bulk': {
            'method': 'POST', 'url': '/messages',
            'decorators': [
                decorators.exception_decorator,
                decorators.return_path_decorator([])
            ],
            'description': (
                'Forward an array of json messages to the rule engine, '
                'time series database and/or document store.'
            ),
            'links': {
                'doc': 'posting-array-of-data'
            },
        },
        'remove': {
            'method': 'DELETE', 'url': '/resources/{}',
            'decorators': DEFAULT_DECORATORS,
            'description': 'Remove all data for a resource.',
            'links': {
                'doc': 'all-data-for-a-resource'
            },
        },
    }

==> waylay_beta-0.5.0-py3-none-any.whl: waylay/service/data/events.py <==
"""REST definitions for the 'series' entity of the 'data' service."""

from waylay.service import WaylayResource
from waylay.service import decorators

DEFAULT_DECORATORS = [decorators.exception_decorator, decorators.return_body_decorator]

RESOURCE_ARG = {
    'name': 'resource_id',
    'type': 'str',
    'description': 'The id of a waylay resource.'
}


class EventsResource(WaylayResource):
    """REST Resource for the 'events' ingestion of the 'data' service."""

    link_roots = {
        'doc': '${doc_url}/api/broker/?id='
    }

    actions = {
        'post': {
            'method': 'POST', 'url': '/events/{}',
            'arguments': [RESOURCE_ARG],
            'decorators': [
                decorators.exception_decorator,
                decorators.return_path_decorator([]),
            ],
            'description': (
                'Forward a json message to the rule engine, '
                'time series database and/or document store for a given resource.'
            ),
            'links': {
                'doc': 'posting-data-to-the-storage-and-rule-engine'
            },
        },
        'bulk': {
            'method': 'POST', 'url': '/messages',
            'returns': [
            ],
            'decorators': [
                decorators.exception_decorator,
                decorators.return_path_decorator([])
            ],
            'description': (
                'Forward an array of json messages to the rule engine, '
                'time series database and/or document store.'
            ),
            'links': {
                'doc': 'posting-array-of-data'
            },
        },
        'remove': {
            'method': 'DELETE', 'url': '/{}',
            'arguments': [RESOURCE_ARG],
            'decorators': DEFAULT_DECORATORS,
            'description': 'Remove all data for a resource.',
            'links': {
                'doc': 'all-data-for-a-resource'
            },
        },
    }

    def get_action_full_url(self, action_name, *parts):
        """Override the regular url computation when not using api gateway."""
        via_gateway = '/data/v1' in self.api_root_url
        if not via_gateway and action_name == 'remove':
            # remove not via api:
            return self.api_root_url + f'resources/{parts[0]}'
        else:
            return super().get_action_full_url(action_name, *parts)
